/* purple */
.c { color: #be63ff } /* Comment */
.c1 { color: #be63ff } /* Comment.Single */
.ch { color: #be63ff } /* Comment.Hashbang */
.cm { color: #be63ff } /* Comment.Multiline */
.cs { color: #be63ff } /* Comment.Special */

/* red */
.err { color: #FF5151 } /* Error */

/* orange */
.m { color: #e87400 } /* Literal.Number */
.il { color: #e87400 } /* Literal.Number.Integer.Long */
.mb { color: #e87400 } /* Literal.Number.Bin */
.mf { color: #e87400 } /* Literal.Number.Float */
.mh { color: #e87400 } /* Literal.Number.Hex */
.mi { color: #e87400 } /* Literal.Number.Integer */
.mo { color: #e87400 } /* Literal.Number.Oct */

.s { color: #e87400 } /* Literal.String */
.sa { color: #e87400 } /* Literal.String.Affix */
.sb { color: #e87400 } /* Literal.String.Backtick */
.sc { color: #e87400 } /* Literal.String.Char */
.dl { color: #e87400 } /* Literal.String.Delimiter */
.sd { color: #e87400 } /* Literal.String.Doc */
.s2 { color: #e87400 } /* Literal.String.Double */
.se { color: #e87400 } /* Literal.String.Escape */
.sh { color: #e87400 } /* Literal.String.Heredoc */
.si { color: #e87400 } /* Literal.String.Interpol */
.sx { color: #e87400 } /* Literal.String.Other */
.sr { color: #e87400 } /* Literal.String.Regex */
.s1 { color: #e87400 } /* Literal.String.Single */
.ss { color: #e87400 } /* Literal.String.Symbol */

/* cyan */
.k { color: #00b6c6 } /* Keyword */
.kc { color: #00b6c6 } /* Keyword.Constant */
.kd { color: #00b6c6 } /* Keyword.Declaration */
.kn { color: #00b6c6 } /* Keyword.Namespace */
.kp { color: #00b6c6 } /* Keyword.Pseudo */
.kr { color: #00b6c6 } /* Keyword.Reserved */

/* indigo */
.kt { color: #8e84ff } /* Keyword.Type */

/* blue */
.na { color: #6397ff } /* Name.Attribute */
.nb { color: #6397ff } /* Name.Builtin */
.nc { color: #6397ff } /* Name.Class */
.no { color: #6397ff } /* Name.Constant */
.nd { color: #6397ff } /* Name.Decorator */
.ni { color: #6397ff } /* Name.Entity */
.ne { color: #6397ff } /* Name.Exception */
.nf { color: #6397ff } /* Name.Function */
.nl { color: #6397ff } /* Name.Label */
.nn { color: #6397ff } /* Name.Namespace */
.nt { color: #6397ff } /* Name.Tag */
.nv { color: #6397ff } /* Name.Variable */
.bp { color: #6397ff } /* Name.Builtin.Pseudo */
.fm { color: #6397ff } /* Name.Function.Magic */
.vc { color: #6397ff } /* Name.Variable.Class */
.vg { color: #6397ff } /* Name.Variable.Global */
.vi { color: #6397ff } /* Name.Variable.Instance */
.vm { color: #6397ff } /* Name.Variable.Magic */

/* magenta */
.cp { color: #de3aff } /* Comment.Preproc */
.cpf { color: #de3aff } /* Comment.PreprocFile */

/* base3 */
.o { color: #b7b3a8 } /* Operator */
.ow { color: #b7b3a8 } /* Operator.Word */

.hll { background-color: #ffffcc }
.gd { color: #A00000 } /* Generic.Deleted */
.gr { color: #FF0000 } /* Generic.Error */
.gh { color: #000080 } /* Generic.Heading */
.gi { color: #00A000 } /* Generic.Inserted */
.go { color: #888888 } /* Generic.Output */
.gp { color: #000080 } /* Generic.Prompt */
.gu { color: #800080 } /* Generic.Subheading */
.gt { color: #0044DD } /* Generic.Traceback */
.w { color: #bbbbbb } /* Text.Whitespace */
